export P=proj5
export V=5.2.0
export B=1
export MAINTAINER=JuergenFischer

savelog() {
	local f=$1
	/bin/rm -f $f.9
	for i in $(seq 8 -1 0); do [ -f "$f.$i" ] && mv $f.$i $f.$(( i + 1 )); done
	[ -f $f ] && mv $f $f.0
}

savelog package.log
exec > >(tee package.log) 2>&1
date

set -e

[ -f proj-$V.tar.gz ] || wget https://download.osgeo.org/proj/proj-$V.tar.gz

[ -f ../CMakeLists.txt ] || tar -C .. -xzf proj-$V.tar.gz --xform s,proj-${V%RC*},.,

if ! [ -d "$OSGEO4W_REP" ]; then
        echo no repository
        exit 1
fi

fetchenv() {
        local IFS
        IFS=
        batch=$1
        shift

        if ! [ -f "$batch" ]; then
                echo "$batch not found"
                return 1
        fi

        srcenv=$(mktemp /tmp/srcenv.XXXXXXXXXX)
        dstenv=$(mktemp /tmp/dstenv.XXXXXXXXXX)
        diffenv=$(mktemp /tmp/diffenv.XXXXXXXXXX)
        envdiff=$(mktemp /tmp/envdiff.XXXXXXXXXX)
        cmd /c set >$srcenv
        cmd /c call $(cygpath -w $batch) "$@" \>nul 2\>nul \& set >$dstenv
        /usr/bin/cat <<EOF >$envdiff
/^+++/d;
/^[^+]/d;
s/^+//;
# s/\\\\/\\\\\\\\/g;
/^PATH=/ {
        s/\\\\/\\//g;
        s#\\([=;]\\)\\([a-zA-Z]\\):#\\1/cygdrive/\\2#g;
        s/;/:/g;
}
s/;/\\\\;/g;
s/^/export /;
s/=/='/;
s/\\\\r//g;
s/\r$/'/;
EOF
        /usr/bin/diff -u $srcenv $dstenv | /usr/bin/sed -f $envdiff >$diffenv
        . $diffenv
        PATH=$PATH:/bin:/usr/bin:/cygdrive/c/windows32/system32:/cygdrive/c/windows
        /bin/rm -f $srcenv $dstenv $diffenv $envdiff
}

for ARCH in ${ARCHS:-x86 x86_64}; do
	export ARCH

	(
		case "$ARCH" in
		x86)
       		export OSGEO4W_ROOT=/c/OSGeo4W
			export CMAKE_GEN="Visual Studio 14 2015"
       		export VCARCH=x86
			;;

		x86_64)
			export OSGEO4W_ROOT=/c/OSGeo4W64
        	export VCARCH=x64
			export CMAKE_GEN="Visual Studio 14 2015 Win64"
			;;

		*)
       		echo invalid arch
       		exit 1
			;;

		esac

		export R=$OSGEO4W_REP/$ARCH/release/proj/$P
		mkdir -p $R

		cat <<EOF >$R/setup.hint
sdesc: "The PROJ library and commands for coordinate system transformations (legacy version 5)"
ldesc: "The PROJ library and commands for coordinate system transformations (legacy version 5)."
category: Libs Commandline_Utilities
requires: msvcrt2015 proj proj-hpgn proj-datumgrid proj-beta2007
maintainer: $MAINTAINER
EOF

		cp ../COPYING $R/$P-$V-$B.txt

		fetchenv $OSGEO4W_ROOT/bin/o4w_env.bat
		fetchenv "/c/Program Files (x86)/Microsoft Visual Studio 14.0/VC/vcvarsall.bat" $VCARCH

		export PATH="/c/Program Files (x86)/Microsoft Visual Studio 14.0/Common7/IDE:/c/Program Files/CMake/bin:$PATH:/bin"
		export INSTDIR=$PWD/install-$ARCH
		export BUILDCONF=RelWithDebInfo

		rm -rf $INSTDIR

		mkdir -p build-$ARCH
		cd build-$ARCH

		cmake -G "$CMAKE_GEN" \
			-DCMAKE_INSTALL_PREFIX=$(cygpath -m $INSTDIR/apps/$P) \
			-DPROJ_LIB_SUBDIR=lib \
			-DPROJ_CMAKE_SUBDIR=share/cmake/proj4 \
			-DPROJ_DATA_SUBDIR=share/proj \
			-DPROJ_INCLUDE_SUBDIR=include \
			-DPROJ_TESTS=OFF \
			-DBUILD_LIBPROJ_SHARED=OFF \
			-DBUILD_SHARED_LIBS=OFF \
			../..

		for i in ZERO_CHECK ALL_BUILD INSTALL; do
			echo "$i: $(date)"
			cmake --build . --target $i --config $BUILDCONF
		done

		v=${V%.*}
		v=${v/./_}

		/bin/tar -C $INSTDIR -cjf $R/$P-$V-$B.tar.bz2 \
			--hard-dereference \
			apps/$P
		
		/bin/tar -C ../.. -cjf $R/$P-$V-$B-src.tar.bz2 \
			osgeo4w/package.sh
	)
done
